@@ -1,10 +1,5 @@
 from typing import Tuple, List
-from nlp_tools import macros as k
-import os
-from nlp_tools.corpus import DataReader
-from nlp_tools import utils
-import logging
-import json
+import random
 
 
 
@@ -14,7 +9,7 @@ class LCQMC(object):
     @classmethod
     def load_data(cls,
                   file_path: str ,
-                  shuffle: bool = True) -> Tuple[List[List[str]], List[List[str]]]:
+                  shuffle: bool = True):
         """
                 Load dataset as sequence labeling format, char level tokenized
 
@@ -29,24 +24,13 @@ class LCQMC(object):
                 Returns:
                     dataset_features and dataset labels
                 """
-        x_data = []
-        y_data = []
+        data = []
         with open(file_path,'r',encoding='utf-8') as fread:
             for index, line in enumerate(fread):
                 x1,x2,label = line.strip().split("\t")
-                x_data.append([x1,x2])
-                y_data.append(label)
+                data.append(([x1,x2],str(label)))
 
         if shuffle:
-            x_data, y_data = utils.unison_shuffled_copies(x_data, y_data)
-        logging.debug(f"loaded {len(x_data)} samples from {file_path}. Sample:\n"
-                      f"x[0]: {x_data[0]}\n"
-                      f"y[0]: {y_data[0]}")
-        return x_data, y_data
+            random.shuffle(data)
+        return data
 
-if __name__ == "__main__":
-    data_path =r'F:\nlp_data\similary\lcqmc\dev.txt'
-    a, b = LCQMC.load_data(data_path)
-    print(a[:2])
-    print(b[:2])
-    print("Hello world")
\ No newline at end of file
