@@ -3,6 +3,7 @@ from nlp_tools.layers.conditional_random_field import KConditionalRandomField
 from nlp_tools.layers.kmax_pool_layer import KMaxPoolingLayer
 from nlp_tools.layers.att_wgt_avg_layer import AttentionWeightedAverageLayer
 from nlp_tools.layers.behdanau_attention import BahdanauAttention
+#from nlp_tools.layers.pool_layer import PoolerInputLayer
 from nlp_tools.loss.r_drop_loss import RDropLoss
 
 from nlp_tools.loss import TextGenerateCrossEntropy
@@ -15,7 +16,12 @@ L.KConditionalRandomField = KConditionalRandomField
 
 
 L.TextGenerateCrossEntropy = TextGenerateCrossEntropy
+from tensorflow.keras.layers import LayerNormalization
 
+class NlpToolsLayerNormalization(LayerNormalization):
+    def __init__(self,
+               **kwargs):
+        super(NlpToolsLayerNormalization,self).__init__(**kwargs)
 
 def resigter_custom_layers(custom_objects: Dict[str, Any]) -> Dict[str, Any]:
     custom_objects['KConditionalRandomField'] = KConditionalRandomField
@@ -24,6 +30,8 @@ def resigter_custom_layers(custom_objects: Dict[str, Any]) -> Dict[str, Any]:
 
     custom_objects['TextGenerateCrossEntropy'] = TextGenerateCrossEntropy
     custom_objects['r_drop_loss'] = RDropLoss(loss_func=None)
+    #custom_objects['PoolerInputLayer'] = PoolerInputLayer
+    custom_objects['NlpToolsLayerNormalization'] = NlpToolsLayerNormalization
 
 
     return custom_objects
\ No newline at end of file
